==> mule-metadata-model-api-1.5.0-20220523-sources.jar: org/mule/metadata/api/model/impl/DefaultIntersectionType.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.api.model.impl;

import static org.apache.commons.lang3.ArrayUtils.addAll;
import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.model.IntersectionType;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.api.visitor.MetadataTypeVisitor;

import java.lang.reflect.Field;
import java.util.List;
import java.util.Map;

public class DefaultIntersectionType extends BaseMetadataType implements IntersectionType {

  private final List<MetadataType> types;

  public DefaultIntersectionType(List<MetadataType> types, MetadataFormat metadataFormat,
                                 Map<Class<? extends TypeAnnotation>, TypeAnnotation> extensions) {
    super(metadataFormat, extensions);
    this.types = types;
  }

  private static final Field[] REFLECTION_FIELDS;
  static {
    try {
      REFLECTION_FIELDS = addAll(BASE_REFLECTION_FIELDS,
                                 DefaultIntersectionType.class.getDeclaredField("types"));
    } catch (NoSuchFieldException e) {
      throw new RuntimeException("Could not resolve field", e);
    }
  }

  @Override
  public Field[] getReflectionComparableFields() {
    return REFLECTION_FIELDS;
  }

  @Override
  public List<MetadataType> getTypes() {
    return types;
  }

  @Override
  public void accept(MetadataTypeVisitor visitor) {
    visitor.visitIntersection(this);
  }
}

==> mule-metadata-model-api-1.6.16-20250220.211726-3-sources.jar: org/mule/metadata/api/model/impl/DefaultIntersectionType.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.api.model.impl;

import static java.util.Collections.addAll;

import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.model.IntersectionType;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.api.visitor.MetadataTypeVisitor;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class DefaultIntersectionType extends BaseMetadataType implements IntersectionType {

  private final List<MetadataType> types;
  private Object[] fieldValues;

  public DefaultIntersectionType(List<MetadataType> types, MetadataFormat metadataFormat,
                                 Map<Class<? extends TypeAnnotation>, TypeAnnotation> extensions) {
    super(metadataFormat, extensions);
    this.types = types;
  }

  @Override
  public Object[] getFieldValues() {
    if (fieldValues == null) {
      fieldValues = createFieldValuesArray();
    }
    return fieldValues;
  }

  private Object[] createFieldValuesArray() {
    List<Object> fieldValues = new ArrayList<>();
    addAll(fieldValues, super.getFieldValues());
    addAll(fieldValues, types);
    return fieldValues.toArray(new Object[fieldValues.size()]);
  }

  @Override
  public List<MetadataType> getTypes() {
    return types;
  }

  @Override
  public void accept(MetadataTypeVisitor visitor) {
    visitor.visitIntersection(this);
  }
}
